summaryrefslogtreecommitdiff
path: root/test/e2e/runlabel_test.go
diff options
context:
space:
mode:
authorJosh Soref <jsoref@users.noreply.github.com>2020-12-21 17:48:43 -0500
committerJosh Soref <jsoref@users.noreply.github.com>2020-12-22 13:34:31 -0500
commit4fa1fce930f13d71f39b65bad3f46f61d961ab51 (patch)
tree3651ceec491317b6ab3aab81c7ab136eb0ff3c02 /test/e2e/runlabel_test.go
parent07663f74c48d11732a3330248f837d5abf86fe9c (diff)
downloadpodman-4fa1fce930f13d71f39b65bad3f46f61d961ab51.tar.gz
podman-4fa1fce930f13d71f39b65bad3f46f61d961ab51.tar.bz2
podman-4fa1fce930f13d71f39b65bad3f46f61d961ab51.zip
Spelling
Signed-off-by: Josh Soref <jsoref@users.noreply.github.com>
Diffstat (limited to 'test/e2e/runlabel_test.go')
-rw-r--r--test/e2e/runlabel_test.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/e2e/runlabel_test.go b/test/e2e/runlabel_test.go
index 7c0b8bc9b..10e16ea23 100644
--- a/test/e2e/runlabel_test.go
+++ b/test/e2e/runlabel_test.go
@@ -114,12 +114,12 @@ var _ = Describe("podman container runlabel", func() {
Expect(result.ExitCode()).To(Equal(0))
})
- It("runlabel should fail with nonexist authfile", func() {
+ It("runlabel should fail with nonexistent authfile", func() {
image := "podman-runlabel-test:podman"
podmanTest.BuildImage(PodmanDockerfile, image, "false")
- // runlabel should fail with nonexist authfile
- result := podmanTest.Podman([]string{"container", "runlabel", "--authfile", "/tmp/nonexist", "RUN", image})
+ // runlabel should fail with nonexistent authfile
+ result := podmanTest.Podman([]string{"container", "runlabel", "--authfile", "/tmp/nonexistent", "RUN", image})
result.WaitWithDefaultTimeout()
Expect(result.ExitCode()).To(Not(Equal(0)))